# eric7.SystemUtilities

Package implementing system level utility functions and classes.

### Modules

DesktopUtilities | Module implementing Linux desktop related utility functions.
FileSystemUtilities | Module implementing file system related utility functions.
OSUtilities | Module implementing Operating System related utility functions.
PySideImporter | Module to check for the presence of PySide2/PySide6 by importing it.
PythonUtilities | Module implementing Python related utility functions.
QtUtilities | Module implementing Qt/PyQt/PySide related utility functions.